==> easybuild-framework-2.6.0.tar.gz: easybuild-framework-2.6.0/easybuild/toolchains/gcccuda.py <==
##
# Copyright 2013-2015 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
# the Hercules foundation (http://www.herculesstichting.be/in_English)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# http://github.com/hpcugent/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
EasyBuild support for a GCC+CUDA compiler toolchain.

@author: Kenneth Hoste (Ghent University)
"""

from easybuild.toolchains.compiler.cuda import Cuda
from easybuild.toolchains.gcc import GccToolchain
from easybuild.tools.toolchain import DUMMY_TOOLCHAIN_NAME


class GccCUDA(GccToolchain, Cuda):
    """Compiler toolchain with GCC and CUDA."""
    NAME = 'gcccuda'

    COMPILER_MODULE_NAME = ['GCC', 'CUDA']
    SUBTOOLCHAIN = GccToolchain.NAME

==> easybuild-framework-3.4.1.tar.gz: easybuild-framework-3.4.1/easybuild/toolchains/gcccuda.py <==
##
# Copyright 2013-2017 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# https://github.com/easybuilders/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
EasyBuild support for a GCC+CUDA compiler toolchain.

:author: Kenneth Hoste (Ghent University)
"""

from easybuild.toolchains.compiler.cuda import Cuda
from easybuild.toolchains.gcc import GccToolchain
from easybuild.tools.toolchain import DUMMY_TOOLCHAIN_NAME


class GccCUDA(GccToolchain, Cuda):
    """Compiler toolchain with GCC and CUDA."""
    NAME = 'gcccuda'

    COMPILER_MODULE_NAME = ['GCC', 'CUDA']
    SUBTOOLCHAIN = GccToolchain.NAME
